==> gazie7.30.zip: gazie/language/english/menu.inc.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */

$strCommon = array('cancel' => " Cancel ",
    'return' => " Return ",
    'submit' => " SUBMIT ",
    'view' => " PREVIEW ",
    'print' => " PRINT ",
    'search' => " Search ",
    'change' => " Change ",
    'all' => 'All',
    'none' => 'None',
    'vall' => " View all ",
    'delete' => " Delete ",
    'first' => "First",
    'prev' => "previous",
    'next' => "next",
    'last' => "Last",
    'order' => "order by ",
    'selall' => "Select all",
    'invsel' => "Invert selection",
    'error' => "ERROR",
    'warning' => "WARNING",
    'cancel' => "Cancel ",
    'update' => "update ",
    'insert' => "insert ",
    'wait' => 'Wait',
    'wait_al' => "Enough! Stop clicking!",
    'notfound' => " not found ",
    'minins' => " to insert minimum ",
    'charat' => " character ",
    'changedate' => "Change date",
    'pullup' => "Pullup this row",
    'thisrow' => " this line",
    'insrow' => "Entered rows",
    'addrow' => "Add row",
    'delrow' => "Delete row",
    'safe' => " if you are sure, click on the ",
    'youdel' => " you are erasing",
    'yes' => "Yes",
    'no' => "No",
    'page' => "page ",
    'of' => " of ",
    'of_the' => " of ",
    'sqn' => "Fields marked with * are required!",
    'canc' => "Undo changes to the form",
    'ins' => "Accepts all post",
    'upd' => "Accepts all changes",
    'caps' => "Caps lock on!",
    'typerow' => array(0 => 'Normal', 1 => 'Forfait', 2 => 'Descriptive', 3 => 'Diff.invoice total', 4 => 'Pension fund', 6 => 'Text', 7 => 'Note only', 8 => 'Invoice only', 11 => 'CIG - fattura elettr.PA', 12 => 'CUP - fattura elettr.PA', 13 => 'IdDocumento - fattura elettr.PA', 14 => 'Data immatricol. fatt.elettr.', 15 => 'Km percorsi fatt.elettr.', 50 => 'Normale c/allegato', 51 => 'Descritt. c/allegato',  90 => 'Asset sales'),
    'search_item' => array('C' => 'Item code', 'B' => 'Barcode', 'D' => 'Description'),
    'tipiva' => array('I' => 'Taxable', 'N' => 'No Taxable', 'E' => 'Exempt', 'S' => 'Not subject', 'C' => 'Excluded', 'D' => 'Indetraibile', 'P' => 'In suspension', 'T' => 'Split payment PA'),
    'duplicate' => 'Duplica',
    'browse_for_file' => 'Browse',
	'refresh' => ' REFRESH ',
	'add' => 'Add movement',
    'order_type' => array(""=>' --------- ',"AGR"=>'Agriculture', "IND"=>'Industrial', "RIC"=>'Research & develop', "PRF"=>'Professional', "ART"=>'Handicraft'),
    'business' => "for the business management.",
    'proj' => "Project manager: ",
    'auth' => "Author web site"
);
?>

==> gazie8.00.zip: gazie/language/english/menu.inc.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */

$strCommon = array('cancel' => " Cancel ",
    'return' => " Return ",
    'submit' => " SUBMIT ",
    'view' => " PREVIEW ",
    'print' => " PRINT ",
    'search' => " Search ",
    'change' => " Change ",
    'all' => 'All',
    'none' => 'None',
    'vall' => " View all ",
    'delete' => " Delete ",
    'first' => "First",
    'prev' => "previous",
    'next' => "next",
    'last' => "Last",
    'order' => "order by ",
    'selall' => "Select all",
    'invsel' => "Invert selection",
    'error' => "ERROR",
    'warning' => "WARNING",
    'cancel' => "Cancel ",
    'update' => "update ",
    'insert' => "insert ",
    'wait' => 'Wait',
    'wait_al' => "Enough! Stop clicking!",
    'notfound' => " not found ",
    'minins' => " to insert minimum ",
    'charat' => " character ",
    'changedate' => "Change date",
    'pullup' => "Pullup this row",
    'thisrow' => " this line",
    'insrow' => "Entered rows",
    'addrow' => "Add row",
    'delrow' => "Delete row",
    'safe' => " if you are sure, click on the ",
    'youdel' => " you are erasing",
    'yes' => "Yes",
    'no' => "No",
    'page' => "page ",
    'of' => " of ",
    'of_the' => " of ",
    'sqn' => "Fields marked with * are required!",
    'canc' => "Undo changes to the form",
    'ins' => "Accepts all post",
    'upd' => "Accepts all changes",
    'caps' => "Caps lock on!",
    'typerow' => array(0 => 'Normal', 1 => 'Forfait', 2 => 'Descriptive', 3 => 'Diff.invoice total', 4 => 'Pension fund', 6 => 'Text', 7 => 'Note only', 8 => 'Invoice only', 11 => 'CIG - fattura elettr.PA', 12 => 'CUP - fattura elettr.PA', 13 => 'IdDocumento - fattura elettr.PA', 14 => 'Data immatricol. fatt.elettr.', 15 => 'Km percorsi fatt.elettr.', 50 => 'Normale c/allegato', 51 => 'Descritt. c/allegato',  90 => 'Asset sales'),
    'search_item' => array('C' => 'Item code', 'B' => 'Barcode', 'D' => 'Description'),
    'tipiva' => array('I' => 'Taxable', 'N' => 'No Taxable', 'E' => 'Exempt', 'S' => 'Not subject', 'C' => 'Excluded', 'D' => 'Indetraibile', 'P' => 'In suspension', 'T' => 'Split payment PA', 'M' => 'Reg.margine/non esp.','R'=>'Reverse Charge'),
    'flux_status_val' => array('#' => array('da inviare','default'), '@' => array('inviata','info'), 'RC' => array('consegnata','success'), 'NS' => array('scartata','danger'), 'MC' => array('non consegnata','warning'), 'NE1' => array('accettata','success'), 'NE2' => array('rifiutata','danger'), 'AT' => array('recapito impossibile','danger'), 'DT' => array('decorrenza termini','warning')),
    'duplicate' => 'Duplica',
    'browse_for_file' => 'Browse',
	'refresh' => ' REFRESH ',
	'add' => 'Add movement',
    'order_type' => array(""=>' --------- ',"AGR"=>'Agriculture', "IND"=>'Industrial', "RIC"=>'Research & develop', "PRF"=>'Professional', "ART"=>'Handicraft'),
    'business' => "for the business management.",
    'proj' => "Project manager: ",
    'auth' => "Author web site"
);
?>
